powered by
A data.table containing id by day observations of Poisson random variables which satisfy the conditional mean assumption of Wooldridge (1999).
id
day
data("ex.dt.good")
A data frame with 500 observations on the following 6 variables.
a factor with levels 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
a numeric vector
fe
x1
x2
y
The data were simulated like y <- rpois(1, exp(fe + x1 + x2)) where fe, x1, and x2 are standard normal random variables. fe varies only across id.
y <- rpois(1, exp(fe + x1 + x2))
Wooldridge, Jeffrey M. (1999): "Distribution-free estimation of some nonlinear panel data models," Journal of Econometrics, 90, 77-97.
# NOT RUN { data("ex.dt.good") str(ex.dt.good) # }
Run the code above in your browser using DataLab