| poisFErobust-package | R Documentation |
Computation of robust standard errors of Poisson fixed effects models, following Wooldridge (1999).
The DESCRIPTION file:
This package was not yet installed at build time.
Index: This package was not yet installed at build time.
Evan Wright [aut, cre]
Maintainer: Evan Wright <enwright@umich.edu>
Wooldridge, Jeffrey M. (1999): "Distribution-free estimation of some nonlinear panel data models," Journal of Econometrics, 90, 77-97.
# ex.dt.good satisfies the conditional mean assumption
data("ex.dt.good")
pois.fe.robust(outcome = "y", xvars = c("x1", "x2"), group.name = "id",
index.name = "day", data = ex.dt.good)
# ex.dt.bad violates the conditional mean assumption
data("ex.dt.bad")
pois.fe.robust(outcome = "y", xvars = c("x1", "x2"), group.name = "id",
index.name = "day", data = ex.dt.bad)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.